// $Id$
//
//  quickreference.m
//  PDFlib
//

#import "quickreference.h"

#if TARGET_OS_IPHONE
#import "PDFlib_ios/PDFlib_objc.h"
#else
#import "PDFlib/PDFlib_objc.h"
#endif

@implementation quickreference

+ (NSData *) run {
      
    NSData *pdfdata=nil;

    const double width = 500, height = 770;
    NSInteger           manual, page;
    NSInteger           font, row, col;
    const NSInteger     maxrow = 2;
    const NSInteger     maxcol = 2;
    NSString           *optlist;
    NSInteger           endpage=0;
    NSInteger           pageno;

    NSString *infile = [[NSBundle mainBundle]
            pathForResource:@"reference" ofType:@"pdf"];
    /* This is where font/image/PDF input files live. Adjust as necessary. */
    NSString *searchpath = [[NSBundle mainBundle] resourcePath];

    
    /* create a new PDFlib object */
    PDFlib *pdflib = [[PDFlib alloc] init];
    if (!pdflib) {
         return nil;
    }
    
    
    @try { 
        [pdflib set_option:@"errorpolicy=exception"];

        // Set the search path for fonts and PDF files
        [pdflib set_option:[NSString stringWithFormat:@"SearchPath={{%@}}", searchpath]];
        [pdflib begin_document:@"" optlist:@""];
        
        [pdflib set_info:@"Creator" value:@"quickreference_ios"];
        [pdflib set_info:@"Author" value:@"Thomas Merz"];
        [pdflib set_info:@"Title" value:@"mini imposition demo (Objective-C)"];
        
        manual = [pdflib open_pdi_document:infile optlist:@""];

        row = 0;
        col = 0;

        /* Get the number of pages in the input document */
        endpage = [pdflib pcos_get_number:manual path:@"length:pages"];

        for (pageno = 1; pageno <= endpage; pageno++)
        {
            if (row == 0 && col == 0)
            {
                [pdflib begin_page_ext:width height:height optlist:@"topdown"];
                font = [pdflib load_font:@"Helvetica-Bold" encoding:@"host" optlist:@""];
                [pdflib setfont:font fontsize:18];
                [pdflib set_text_pos:24 y:24];
                [pdflib show:@"PDFlib Quick Reference"];
            }

            page = [pdflib open_pdi_page:manual pagenumber:pageno optlist:@""];

            optlist =  [NSString stringWithFormat:@"scale %f", 1.0 / maxrow];
            [pdflib fit_pdi_page:page x:width/maxcol*col y:(row + 1) * height/maxrow optlist:optlist];
            [pdflib close_pdi_page:page];

            col++;
            if (col == maxcol)
            {
                col = 0;
                row++;
            }
            if (row == maxrow)
            {
                row = 0;
                [pdflib end_page_ext:@""];
            }
        }

        /* finish the last partial page */
        if (row != 0 || col != 0)
            [pdflib end_page_ext:@""];

        [pdflib end_document:@""];
        [pdflib close_pdi_document:manual];

        pdfdata = [pdflib get_buffer];
    } 
    @catch (PDFlibException *ex) { 
        NSString * errorMessage = 
	    [NSString stringWithFormat:@"PDFlib error %ld in '%@': %@",
            (long)[ex get_errnum], [ex get_apiname], [ex get_errmsg]];
#if TARGET_OS_IPHONE
        UIAlertView *alert = [[UIAlertView alloc] 
            initWithTitle:[ex name] message:errorMessage
            delegate:self cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
        [alert show];
#else
        NSAlert *alert = [[NSAlert alloc] init];
        [alert setMessageText: errorMessage];
        [alert runModal];
#endif
    }
    @catch (NSException *ex) { 
#if TARGET_OS_IPHONE
        UIAlertView *alert = [[UIAlertView alloc] 
            initWithTitle:[ex name] message:[ex reason]
            delegate:self cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
        [alert show];
#else
        NSAlert *alert = [[NSAlert alloc] init];
        [alert setMessageText: [ex reason]];
        [alert runModal];
#endif
    } 
    return pdfdata;
}

@end
